@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -54,7 +54,7 @@ def get_next_arguments(action, type="input"):
     return req, non_req
 
 
-def unravel(l):
+def unravel(list_):
     """
     Unravel Union node to get all permutations of types for each action
 
@@ -68,8 +68,8 @@ def unravel(l):
 
     """
 
-    result = [l]
-    for i, x in enumerate(l):
+    result = [list_]
+    for i, x in enumerate(list_):
         if len(list(x[1])) > 1:
             members = list(x[1])
             temp = copy.deepcopy(result)
