@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2019, QIIME 2 development team.
+# Copyright (c) 2016-2020, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -12,14 +12,14 @@ import qiime2.core.type.parse as _parse
 from qiime2.core.type import (
     is_semantic_type, is_primitive_type, is_collection_type, is_metadata_type,
     is_visualization_type, interrogate_collection_type, parse_primitive,
-    is_union)
+    is_union, is_metadata_column_type)
 
 
 __all__ = [
     'is_semantic_type', 'is_primitive_type', 'is_collection_type',
     'is_metadata_type', 'is_visualization_type', 'interrogate_collection_type',
     'type_from_ast', 'parse_primitive', 'parse_type', 'parse_format',
-    'actions_by_input_type', 'is_union',
+    'actions_by_input_type', 'is_union', 'is_metadata_column_type',
 ]
 
 
